#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import, division, print_function, unicode_literals


__license__   = 'GPL v3'
__copyright__ = u'2019, Jürgen Habelt <juergen@habelt-jena.de>'
__docformat__ = 'restructuredtext en'

import sys, os, re
from os.path import expanduser
from calibre.utils.config import config_dir


class Invoker():
    '''
    Responsible for invoking the Ruby script
    '''
    
    def __init__(self, settings):
        '''
        Initialization
        '''
        self.settings = settings
        
        
    def invoke(self, book, result):
        '''
        Invokes the Ruby script to extract book marks
        '''
        cmd = self.build_command_line(book, result)
        return os.system(cmd)
        
        
    def build_command_line(self, book, result):
        '''
        Builds the command line
        '''
        script_dir = os.path.join(config_dir, 'plugins', 'DefineContent', 'scripts')
        
        cmd = '%s' % self.settings['ruby']
        cmd += ' -C "%s"' % script_dir
        cmd += ' -I "%s"' % script_dir
        cmd += ' HtmlGenerator.rb'
        
        cmd += ' --path "%s"' % book
        cmd += ' --result "%s"' % result
        cmd += ' --tool "%s"' % self.settings['pdftk']
        cmd += ' --level %d' % self.settings['max_level']
        
        if self.settings['omit']:
            cmd += ' --omit'
        if self.settings['continuous']:
            cmd += ' --continuous'
        if self.settings['use_strip']:
            cmd += ' --strip "%s"' % self.settings['strip']
            
        cmd += ' >>"%s"' % self.settings['log_path']
            
        return cmd
                    